@@ -34,12 +34,17 @@
 #ifndef __QGPGME_UTIL_H__
 #define __QGPGME_UTIL_H__
 
+#include <QStringList>
+
 #include <gpgme.h>
 
 #include <string>
 #include <vector>
 
-class QStringList;
+namespace GpgME
+{
+class Key;
+}
 
 static inline gpgme_error_t make_error(gpgme_err_code_t code)
 {
@@ -48,4 +53,6 @@ static inline gpgme_error_t make_error(gpgme_err_code_t code)
 
 std::vector<std::string> toStrings(const QStringList &l);
 
+QStringList toFingerprints(const std::vector<GpgME::Key> &keys);
+
 #endif // __QGPGME_UTIL_H__
